NumPy Methods Optimized by Riptable for FastArrays
**************************************************

When you call the NumPy method, the Riptable version is called instead.


Basic NumPy Methods
===================

* copy()
* astype()
* squeeze()

NumPy Unary Operators
=====================

* absolute()
* negative()
* cos()
* sin()
* exp()
* log()
* log10()
* sqrt()
* ceil()
* trunc()
* floor()
* fabs()
* modf()
* logical_not()

NumPy Binary Operators
======================

* add()
* subtract()
* multiply()
* divide()
* floor_divide()
* true_divide()
* greater()
* greater_equal()
* less()
* less_equal()
* equal()
* not_equal()
* logical_and()
* logical_or()
* logical_xor()
* maximum()
* minimum()

NumPy Reduce Methods
====================

* nansum()